@@ -26,8 +26,7 @@ from capstone import *
 from . import gadget
 try:
     import sys
-    if sys.version_info.major < 3:
-        import archinfo
+    import archinfo
 except:
     pass
 
@@ -354,7 +353,7 @@ class ArchitectureArm(Architecture):
         self._endings[gadget.GadgetType.ROP] = [(b'[\x01-\xff]\x80\xbd\xe8', 4)] # pop {[reg]*,pc}
         self._endings[gadget.GadgetType.JOP] = [(b'[\x10-\x1e]\xff\x2f\xe1', 4), # bx <reg>
                                                 (b'[\x30-\x3e]\xff\x2f\xe1', 4), # blx <reg>
-
+                                                (b'[\x00-\x0f]\xf0\xa0\xe1', 4), # mov pc, <reg>
                                                 (b'\x01\x80\xbd\xe8', 4)] # ldm sp! ,{pc}
 
 
@@ -372,7 +371,7 @@ class ArchitectureArmBE(ArchitectureArm):
         self._endings[gadget.GadgetType.ROP] = [(b'\xe8\xbd\x80[\x01-\xff]', 4)] # pop {[reg]*,pc}
         self._endings[gadget.GadgetType.JOP] = [(b'\xe1\x2f\xff[\x10-\x1e]', 4), # bx <reg>
                                                 (b'\xe1\x2f\xff[\x30-\x3e]', 4), # blx <reg>
-
+                                                (b'\xe1\xa0\xf0[\x00-\x0f]', 4), # mov pc, <reg>
                                                 (b'\xe8\xdb\x80\x01', 4)] # ldm sp! ,{pc}
 
 class ArchitectureArmThumb(Architecture):
@@ -408,7 +407,7 @@ class ArchitectureArm64(Architecture):
         if 'archinfo' in globals():
             self._info = archinfo.ArchAArch64()
         if 'keystone' in globals():
-            self._ksarch = (keystone.KS_ARCH_ARM64, keystone.KS_MODE_BIG_ENDIAN)
+            self._ksarch = (keystone.KS_ARCH_ARM64, keystone.KS_MODE_LITTLE_ENDIAN)
 
     def _initGadgets(self):
         super(ArchitectureArm64, self)._initGadgets()
